#!/usr/bin/env node
import { prepareCli, Command, pico, envinfo, gs } from "@mango-scripts/utils";
import webpackDev from "./webpack/scripts/dev.mjs";
import webpackBuild from "./webpack/scripts/build.mjs";
import webpackInspect from "./webpack/scripts/inspect.mjs";
import rsbuildDev from "./rsbuild/scripts/dev.mjs";
import rsbuildBuild from "./rsbuild/scripts/build.mjs";
import rsbuildInspect from "./rsbuild/scripts/inspect.mjs";
const { name, version } = prepareCli();
console.log(gs("@mango-scripts/react-scripts\n"));
const program = new Command();
program.version(`${name} ${version}`).usage("<command> [options]");
program.command("dev").description("\u542F\u52A8\u5F00\u53D1\u670D\u52A1\u5668").option(
  "-m --mode <mode>",
  "\u6307\u5B9A\u73AF\u5883\u6A21\u5F0F (\u9ED8\u8BA4\u503C\uFF1Adevelopment)",
  "development"
).option(
  "-b --bundler <bundler>",
  "\u6307\u5B9A\u5E95\u5C42\u6784\u5EFA\u5DE5\u5177 (\u9ED8\u8BA4\u503C\uFF1Awebpack)",
  "webpack"
).allowUnknownOption().action((options) => {
  const { mode, bundler } = options;
  if (bundler === "rsbuild") {
    rsbuildDev(mode);
  } else {
    webpackDev(mode);
  }
});
program.command("build").description("\u6784\u5EFA\u6253\u5305\u5E94\u7528").option("-m --mode <mode>", "\u6307\u5B9A\u73AF\u5883\u6A21\u5F0F (\u9ED8\u8BA4\u503C\uFF1Aproduction)", "production").option(
  "-b --bundler <bundler>",
  "\u6307\u5B9A\u5E95\u5C42\u6784\u5EFA\u5DE5\u5177 (\u9ED8\u8BA4\u503C\uFF1Awebpack)",
  "webpack"
).allowUnknownOption().action((options) => {
  const { mode, bundler } = options;
  if (bundler === "rsbuild") {
    rsbuildBuild(mode);
  } else {
    webpackBuild(mode);
  }
});
program.command("inspect").description("\u6253\u5370\u914D\u7F6E").option("-m --mode <mode>", "\u6307\u5B9A\u73AF\u5883\u6A21\u5F0F (\u9ED8\u8BA4\u503C\uFF1Aproduction)", "production").option(
  "-b --bundler <bundler>",
  "\u6307\u5B9A\u5E95\u5C42\u6784\u5EFA\u5DE5\u5177 (\u9ED8\u8BA4\u503C\uFF1Awebpack)",
  "webpack"
).allowUnknownOption().action((options) => {
  const { mode, bundler } = options;
  if (bundler === "rsbuild") {
    rsbuildInspect(mode);
  } else {
    webpackInspect(mode);
  }
});
program.command("info").description("\u6253\u5370\u8FD0\u884C\u73AF\u5883\u53C2\u6570").action(() => {
  console.log(pico.bold("\nEnvironment Info:"));
  envinfo.run(
    {
      System: ["OS", "CPU", "Memory", "Shell"],
      Binaries: ["Node", "Yarn", "npm"],
      Browsers: ["Chrome", "Edge", "Firefox", "Safari"],
      npmPackages: "/**/{typescript,*react*}"
    },
    {
      showNotFound: true,
      duplicates: true,
      fullTree: true
    }
  ).then(console.log);
});
program.on("command:*", ([cmd]) => {
  program.outputHelp();
  console.log(pico.red(`Unknown command ${pico.yellow(cmd)}.`));
  console.log();
  process.exitCode = 1;
});
program.on("--help", () => {
  console.log();
  console.log(
    `  Run ${pico.cyan(
      `${name} <command> --help`
    )} for detailed usage of given command.`
  );
  console.log();
});
program.commands.forEach((c) => c.on("--help", () => console.log()));
program.parse(process.argv);
