const base64SourceMap = (source) => {
  const base64 = Buffer.from(JSON.stringify(source.map()), "utf8").toString(
    "base64"
  );
  return `data:application/json;charset=utf-8;base64,${base64}`;
};
const getSourceById = (server, id) => {
  const module = Array.from(server._stats.compilation.modules).find(
    (m) => server._stats.compilation.chunkGraph.getModuleId(m) === id
  );
  return module.originalSource();
};
function createEvalSourceMapMiddleware(server) {
  return function handleWebpackInternalMiddleware(req, res, next) {
    if (req.url.startsWith("/__get-internal-source")) {
      const fileName = req.query.fileName;
      const id = fileName.match(/webpack-internal:\/\/\/(.+)/)?.[1];
      if (!id || !server._stats) {
        next();
        return;
      }
      const source = getSourceById(server, id);
      const sourceMapURL = `//# sourceMappingURL=${base64SourceMap(source)}`;
      const sourceURL = `//# sourceURL=webpack-internal:///${id}`;
      res.end(`${source.source()}
${sourceMapURL}
${sourceURL}`);
    } else {
      next();
    }
  };
}
export {
  createEvalSourceMapMiddleware as default
};
