import { pico } from "@mango-scripts/utils";
import { createRsbuild } from "@rsbuild/core";
import choosePort from "../../common/utils/choosePort.mjs";
import checkRequiredFiles from "../../common/utils/checkRequiredFiles.mjs";
import { getLocalHost } from "../../common/utils/index.mjs";
import { applyEnv } from "../../common/getEnv.mjs";
import { getPaths } from "../../common/getPaths.mjs";
import { getRsbuildConfig } from "../config/config.mjs";
import { getUserConfig } from "../../webpack/config/getUserConfig.mjs";
process.on("unhandledRejection", (err) => {
  throw err;
});
const dev = async (mode) => {
  try {
    const userConfig = await getUserConfig();
    const paths = getPaths(userConfig);
    applyEnv(mode, "development", paths);
    if (!checkRequiredFiles([paths.appHtml, paths.appIndexJs])) {
      process.exit(1);
    }
    const useLocalHost = process.env.USE_LOCAL_HOST === "true";
    const defaultPort = Number(process.env.PORT || "3000");
    const host = useLocalHost && getLocalHost() || "0.0.0.0";
    const port = await choosePort(host, defaultPort);
    if (port == null) {
      console.log(pico.red("No port found, please check your environment"));
      return;
    }
    const config = await getRsbuildConfig(
      {
        server: {
          host,
          port
        }
      },
      paths
    );
    const rsbuild = await createRsbuild({
      cwd: process.cwd(),
      rsbuildConfig: config
    });
    const { server: devServer } = await rsbuild.startDevServer();
    ["SIGINT", "SIGTERM"].forEach((sig) => {
      process.on(sig, () => {
        devServer.close();
        process.exit();
      });
    });
    if (process.env.CI !== "true") {
      process.stdin.on("end", () => {
        devServer.close();
        process.exit();
      });
    }
  } catch (err) {
    if (err && err.message) {
      console.log(err.message);
    }
    process.exit(1);
  }
};
var dev_default = dev;
export {
  dev_default as default
};
