import path from "node:path";
import { fs, pico } from "@mango-scripts/utils";
import resolve from "resolve";
const getAdditionalModulePaths = (paths, options = {}) => {
  const baseUrl = options.baseUrl;
  if (!baseUrl) {
    return "";
  }
  const baseUrlResolved = path.resolve(paths.appPath, baseUrl);
  if (path.relative(paths.appNodeModules, baseUrlResolved) === "") {
    return null;
  }
  if (path.relative(paths.appSrc, baseUrlResolved) === "") {
    return [paths.appSrc];
  }
  if (path.relative(paths.appPath, baseUrlResolved) === "") {
    return null;
  }
  throw new Error(
    pico.red(
      pico.bold(
        "Your project's `baseUrl` can only be set to `src` or `node_modules`. Create React App does not support other values at this time."
      )
    )
  );
};
const getWebpackAliases = (paths, options = {}) => {
  const baseUrl = options.baseUrl;
  if (!baseUrl) {
    return {};
  }
  const baseUrlResolved = path.resolve(paths.appPath, baseUrl);
  if (path.relative(paths.appPath, baseUrlResolved) === "") {
    return {
      src: paths.appSrc
    };
  } else {
    return {};
  }
};
const getModules = (paths) => {
  const hasTsConfig = fs.pathExistsSync(paths.appTsConfig);
  const hasJsConfig = fs.pathExistsSync(paths.appJsConfig);
  if (hasTsConfig && hasJsConfig) {
    throw new Error(
      "You have both a tsconfig.json and a jsconfig.json. If you are using TypeScript please remove your jsconfig.json file."
    );
  }
  let config;
  if (hasTsConfig) {
    const ts = require(resolve.sync("typescript", {
      basedir: paths.appNodeModules
    }));
    config = ts.readConfigFile(paths.appTsConfig, ts.sys.readFile).config;
  } else if (hasJsConfig) {
    config = require(paths.appJsConfig);
  }
  config = config || {};
  const options = config.compilerOptions || {};
  const additionalModulePaths = getAdditionalModulePaths(paths, options);
  return {
    additionalModulePaths,
    webpackAliases: getWebpackAliases(paths, options),
    hasTsConfig
  };
};
export {
  getModules
};
